#!/usr/bin/perl -w

use strict;

# -----------------------------------------------------------------------------------
die "Bad args count!" unless $#ARGV == 0;
# -----------------------------------------------------------------------------------

my $mbox = $ARGV[0];
my %old_posts;
my %new_posts;
my $biff = 0;

# -----------------------------------------------------------------------------------
sub analyze_posts {
  my ($file, $posts) = @_;

  while(my $line = <$file>) {
    chomp $line;
    my ($code, $count, $group) = $line =~ /([0-9]+) [0-9]+ [0-9]+ ([0-9]+) (.*)/;
    if($code && $code == 211 && $count && $group) {
      $$posts{ $group } = $count;
    }
  }
}
# -----------------------------------------------------------------------------------

# Old messages
# ------------
if( open(MBOXFILE, "<$mbox") ) {
  while(my $line = <MBOXFILE>) {
    chomp $line;
    last if $line =~ /^[\r\n]*$/;
  }

  analyze_posts(*MBOXFILE, \%old_posts);
  close(MBOXFILE);
}

# New messages
# ------------
analyze_posts(*STDIN, \%new_posts);


# Compare last msg ids
# --------------------
foreach my $key (keys %new_posts) {
  if(!$old_posts{$key} || $new_posts{$key} && $old_posts{$key} != $new_posts{$key}) {
    $biff = 1;
  }
  $old_posts{$key} = $new_posts{$key};
}

#exit 0 unless $biff;

# Write new state to mbox
# -----------------------
die "Couldn't write mbox file!" unless open(MBOXFILE, ">$mbox");

print MBOXFILE "From - Sun Sep 14 20:16:28 2008\n";
print MBOXFILE "X-Mozilla-Status: 000".($biff ? '0' : '1')."\n";
print MBOXFILE <<EOF
From: NNTP Notifier <notifier.localhost>
Subject: New posts

EOF
;

foreach my $key (keys %old_posts) {
  print MBOXFILE "211 0 0 ".$old_posts{ $key }." $key\n";
}
close(MBOXFILE);

exit $biff;
